package com.zehong.system.service.impl;

import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import com.zehong.system.domain.TSafeMeetingLedger;
import com.zehong.system.mapper.TSafeMeetingLedgerMapper;
import com.zehong.system.service.ITSafeMeetingLedgerService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 安全例会台账Service业务层处理
 * 
 * @author zehong
 * @date 2026-03-27
 */
@Service
public class TSafeMeetingLedgerServiceImpl implements ITSafeMeetingLedgerService 
{
    @Resource
    private TSafeMeetingLedgerMapper tSafeMeetingLedgerMapper;

    /**
     * 查询安全例会台账
     * 
     * @param meetingId 安全例会台账ID
     * @return 安全例会台账
     */
    @Override
    public TSafeMeetingLedger selectTSafeMeetingLedgerById(Long meetingId)
    {
        return tSafeMeetingLedgerMapper.selectTSafeMeetingLedgerById(meetingId);
    }

    /**
     * 查询安全例会台账列表
     * 
     * @param tSafeMeetingLedger 安全例会台账
     * @return 安全例会台账
     */
    @Override
    public List<TSafeMeetingLedger> selectTSafeMeetingLedgerList(TSafeMeetingLedger tSafeMeetingLedger)
    {
        return tSafeMeetingLedgerMapper.selectTSafeMeetingLedgerList(tSafeMeetingLedger);
    }

    /**
     * 新增安全例会台账
     * 
     * @param tSafeMeetingLedger 安全例会台账
     * @return 结果
     */
    @Override
    public int insertTSafeMeetingLedger(TSafeMeetingLedger tSafeMeetingLedger)
    {
        tSafeMeetingLedger.setCreateTime(DateUtils.getNowDate());
        tSafeMeetingLedger.setCreateBy(SecurityUtils.getLoginUser().getUser().getNickName());
        return tSafeMeetingLedgerMapper.insertTSafeMeetingLedger(tSafeMeetingLedger);
    }

    /**
     * 修改安全例会台账
     * 
     * @param tSafeMeetingLedger 安全例会台账
     * @return 结果
     */
    @Override
    public int updateTSafeMeetingLedger(TSafeMeetingLedger tSafeMeetingLedger)
    {
        tSafeMeetingLedger.setUpdateTime(DateUtils.getNowDate());
        tSafeMeetingLedger.setUpdateBy(SecurityUtils.getLoginUser().getUser().getNickName());
        return tSafeMeetingLedgerMapper.updateTSafeMeetingLedger(tSafeMeetingLedger);
    }

    /**
     * 批量删除安全例会台账
     * 
     * @param meetingIds 需要删除的安全例会台账ID
     * @return 结果
     */
    @Override
    public int deleteTSafeMeetingLedgerByIds(Long[] meetingIds)
    {
        return tSafeMeetingLedgerMapper.deleteTSafeMeetingLedgerByIds(meetingIds);
    }

    /**
     * 删除安全例会台账信息
     * 
     * @param meetingId 安全例会台账ID
     * @return 结果
     */
    @Override
    public int deleteTSafeMeetingLedgerById(Long meetingId)
    {
        return tSafeMeetingLedgerMapper.deleteTSafeMeetingLedgerById(meetingId);
    }
}
